@@ -82,6 +82,8 @@ class FixedScaleOffset(Codec):
             self.astype = self.dtype
         else:
             self.astype = np.dtype(astype)
+        if self.dtype == object or self.astype == object:
+            raise ValueError('object arrays are not supported')
 
     def encode(self, buf):
 
